@@ -689,7 +689,7 @@ PetscErrorCode DMDAGetInterpolationType(DM da, DMDAInterpolationType *ctype)
   Level: intermediate
 
   Notes:
-  In 2d the array is of length 9, in 3d of length 27
+  In 2d the `ranks` is of length 9, in 3d of length 27
 
   Not supported in 1d
 
