@@ -273,6 +273,7 @@ static PetscErrorCode PetscLogHandlerContextCreate_Default(PetscLogHandler_Defau
   PetscCall(PetscLogStageInfoArrayCreate(8, &def->stages));
   PetscCall(PetscLogActionArrayCreate(64, &def->petsc_actions));
   PetscCall(PetscLogObjectArrayCreate(64, &def->petsc_objects));
+  PetscCall(PetscSpinlockCreate(&def->lock));
 
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-log_include_actions", &def->petsc_logActions, NULL));
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-log_include_objects", &def->petsc_logObjects, NULL));
@@ -289,6 +290,7 @@ static PetscErrorCode PetscLogHandlerDestroy_Default(PetscLogHandler h)
   PetscCall(PetscLogStageInfoArrayDestroy(&def->stages));
   PetscCall(PetscLogActionArrayDestroy(&def->petsc_actions));
   PetscCall(PetscLogObjectArrayDestroy(&def->petsc_objects));
+  PetscCall(PetscSpinlockDestroy(&def->lock));
   if (def->eventInfoMap_th) {
     PetscEventPerfInfo **array;
     PetscInt             n, off = 0;
@@ -549,7 +551,7 @@ static PetscErrorCode PetscLogHandlerEventBegin_Default(PetscLogHandler h, Petsc
       b1[0] = -o1->cidx;
       b1[1] = o1->cidx;
       PetscCall(MPIU_Allreduce(b1, b2, 2, MPIU_INT64, MPI_MAX, PetscObjectComm(o1)));
-      PetscCheck(-b2[0] == b2[1], PETSC_COMM_SELF, PETSC_ERR_PLIB, "Collective event %s not called collectively %" PetscInt64_FMT " != %" PetscInt64_FMT, event_info.name, b1[1], b2[1]);
+      PetscCheck(-b2[0] == b2[1], PETSC_COMM_SELF, PETSC_ERR_PLIB, "Collective event %s not called collectively %" PetscInt64_FMT " != %" PetscInt64_FMT, event_info.name, -b2[0], b2[1]);
     }
   }
   /* Synchronization */
@@ -614,7 +616,7 @@ static PetscErrorCode PetscLogHandlerEventEnd_Default(PetscLogHandler h, PetscLo
       b1[0] = -o1->cidx;
       b1[1] = o1->cidx;
       PetscCall(MPIU_Allreduce(b1, b2, 2, MPIU_INT64, MPI_MAX, PetscObjectComm(o1)));
-      PetscCheck(-b2[0] == b2[1], PETSC_COMM_SELF, PETSC_ERR_PLIB, "Collective event %s not called collectively %" PetscInt64_FMT " != %" PetscInt64_FMT, event_info.name, b1[1], b2[1]);
+      PetscCheck(-b2[0] == b2[1], PETSC_COMM_SELF, PETSC_ERR_PLIB, "Collective event %s not called collectively %" PetscInt64_FMT " != %" PetscInt64_FMT, event_info.name, -b2[0], b2[1]);
     }
   }
   if (def->petsc_logActions) {
@@ -1222,7 +1224,7 @@ static PetscErrorCode PetscLogViewWarnNoGpuAwareMpi(PetscViewer viewer)
 
 static PetscErrorCode PetscLogViewWarnGpuTime(PetscViewer viewer)
 {
-#if defined(PETSC_HAVE_DEVICE)
+#if defined(PETSC_HAVE_DEVICE) && !defined(PETSC_HAVE_KOKKOS_WITHOUT_GPU)
 
   PetscFunctionBegin;
   if (!PetscLogGpuTimeFlag || petsc_gflops == 0) PetscFunctionReturn(PETSC_SUCCESS);
@@ -1268,7 +1270,7 @@ static PetscErrorCode PetscLogHandlerView_Default_Info(PetscLogHandler handler,
   PetscLogEvent event;
   char          version[256];
   MPI_Comm      comm;
-#if defined(PETSC_HAVE_DEVICE)
+#if defined(PETSC_HAVE_DEVICE) && !defined(PETSC_HAVE_KOKKOS_WITHOUT_GPU)
   PetscInt64 nas = 0x7FF0000000000002;
 #endif
   PetscLogGlobalNames global_stages, global_events;
@@ -1302,10 +1304,11 @@ static PetscErrorCode PetscLogHandlerView_Default_Info(PetscLogHandler handler,
 
 #if defined(PETSC_HAVE_CUPM)
   const char *cupm = PetscDefined(HAVE_CUDA) ? "CUDA" : "HIP";
-  if (PetscDeviceCUPMRuntimeArch) PetscCall(PetscViewerASCIIPrintf(viewer, "%s on a %s named %s with %d processor(s) and %s architecture %d, by %s on %s\n", pname, arch, hostname, size, cupm, PetscDeviceCUPMRuntimeArch, username, date));
+  if (PetscDeviceCUPMRuntimeArch)
+    PetscCall(PetscViewerASCIIPrintf(viewer, "%s on a %s named %s with %d process%s and %s architecture %d, by %s on %s\n", pname, arch, hostname, size, size > 1 ? "es" : "", cupm, PetscDeviceCUPMRuntimeArch, username, date));
   else
 #endif
-    PetscCall(PetscViewerASCIIPrintf(viewer, "%s on a %s named %s with %d processor(s), by %s on %s\n", pname, arch, hostname, size, username, date));
+    PetscCall(PetscViewerASCIIPrintf(viewer, "%s on a %s named %s with %d process%s, by %s on %s\n", pname, arch, hostname, size, size > 1 ? "es" : "", username, date));
 
 #if defined(PETSC_HAVE_OPENMP)
   PetscCall(PetscViewerASCIIPrintf(viewer, "Using %" PetscInt_FMT " OpenMP threads\n", PetscNumOMPThreads));
@@ -1607,7 +1610,7 @@ static PetscErrorCode PetscLogHandlerView_Default_Info(PetscLogHandler handler,
           mint = 0;
         }
         PetscCheck(minf >= 0.0, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Minimum flop %g over all processors for %s is negative! Not possible!", minf, event_name);
-#if defined(PETSC_HAVE_DEVICE)
+#if defined(PETSC_HAVE_DEVICE) && !defined(PETSC_HAVE_KOKKOS_WITHOUT_GPU)
         /* Put NaN into the time for all events that may not be time accurately since they may happen asynchronously on the GPU */
         if (!PetscLogGpuTimeFlag && petsc_gflops > 0) {
           memcpy(&gmaxt, &nas, sizeof(PetscLogDouble));
